@@ -3,7 +3,7 @@ package Locale::Maketext::Utils;
 # these work fine, but are not used in production
 # use strict;
 # use warnings;
-$Locale::Maketext::Utils::VERSION = '0.41';
+$Locale::Maketext::Utils::VERSION = '0.42';
 
 use Locale::Maketext 1.21 ();
 use Locales 0.26          ();
@@ -396,6 +396,7 @@ sub lextext {
     }
 
     $@ = $at;    # Put $@ back in case we altered it along the way.
+    return $phrase if !defined $value || $value eq '';
     return $value;
 }
 
@@ -647,9 +648,10 @@ sub get_asset {
 
     my $loc_obj = $lh->get_locales_obj($tag);
 
+    my $root = $tag || $lh->get_language_tag;
     my $ret;
     my $loc;                                                                            # buffer
-    for $loc ( $loc_obj->get_fallback_list( $lh->{'Locales.pm'}{'get_fallback_list_special_lookup_coderef'} ) ) {
+    for $loc ( ( substr( $root, 0, 2 ) eq 'i_' ? $root : () ), $loc_obj->get_fallback_list( $lh->{'Locales.pm'}{'get_fallback_list_special_lookup_coderef'} ) ) {
 
         # allow $code to be a soft ref?
         # no strict 'refs';
@@ -757,7 +759,7 @@ sub numf {
     # method call if we already have the Locales object that belongs to the handle's locale.
     $handle->{'Locales.pm'}{'_main_'} ||= $handle->get_locales_obj();
 
-    return $handle->{'Locales.pm'}{'_main_'}->get_formatted_decimal( $num, $max_decimal_places );
+    return $handle->{'Locales.pm'}{'_main_'}->get_formatted_decimal( $num, $max_decimal_places ) || 0;
 }
 
 #### / CLDR aware numf() w/ decimal/formatter ##
